@@ -194,7 +194,7 @@ class QueueProxy(DataFacts, Queue):
     def task_failed(self,update=lambda x:None):
         update(self.current_task)
 
-        self.logger.error("current task updated for failed task, execution info: %s", self.current_task.execution_info)
+        self.logger.error("current task %s updated for failed task, execution info: %s", self.current_task.key, self.current_task.execution_info)
 
         r = self.client.worker.failed(worker_id=self.worker_id, 
                                       queue=self.queue, 
